@@ -1,6 +1,7 @@
 #include <stdint.h>
 #include <time.h>
-#ifdef USE_PLEDGE
+
+#ifdef __OpenBSD__
 #include <unistd.h>
 #else
 #define pledge(p1,p2) 0
@@ -11,8 +12,6 @@ size_t strlcat(char *, const char *, size_t);
 #undef strlcpy
 size_t strlcpy(char *, const char *, size_t);
 
-#define ISUTF8(c) (((c) & 0xc0) != 0x80)
-
 /* feed info */
 struct feed {
 	char *        name;     /* feed name */
